FileStreamAccumulator class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
appendUrl(
{required String itemId, required String url, String? turnId, String? senderName}) → AccumulatedFileStream -
clear(
) → void -
complete(
String itemId, {String status = 'completed'}) → AccumulatedFileStream? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
String itemId) → AccumulatedFileStream? -
toString(
) → String -
A string representation of this object.
inherited
-
upsert(
{required String itemId, String? turnId, String? senderName}) → AccumulatedFileStream
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String itemId) → AccumulatedFileStream?