TextStreamAccumulator class

Constructors

TextStreamAccumulator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

appendDelta({required String itemId, required String delta, String? turnId, String? senderName, String? phase}) AccumulatedTextStream
clear() → void
complete(String itemId, {String status = 'completed'}) AccumulatedTextStream?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String itemId) AccumulatedTextStream?
toString() String
A string representation of this object.
inherited
upsert({required String itemId, String? turnId, String? senderName, String? phase}) AccumulatedTextStream

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String itemId) AccumulatedTextStream?