AgentThreadMessageStatusStore class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
AgentMessage message, {String? path}) → bool -
clearThread(
String path) → void -
hasThread(
String path) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
state(
{required String path, ChatThreadStatusState? previous, required bool supportsAgentMessages}) → ChatThreadStatusState -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited