AgentUsageSnapshot class

Constructors

AgentUsageSnapshot({required String threadPath, required int contextUsedTokens, required int? contextTotalTokens, required double? totalTokens, required Map<String, double> usage, String? compactionMode, int? compactionThreshold, String? turnId})
const

Properties

compactionMode String?
final
compactionThreshold int?
final
contextTotalTokens int?
final
contextUsedTokens int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threadPath String
final
totalTokens double?
final
turnId String?
final
usage Map<String, double>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromPayload(Map<String, Object?> payload) AgentUsageSnapshot?