ChatThread class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ChatThread
Constructors
-
ChatThread({Key? key, required String path, required RoomClient room, GlobalKey<
State< ? composerKey, List<StatefulWidget> >Participant> ? participants, List<String> ? participantNames, bool includeLocalParticipant = true, bool startChatCentered = false, ChatMessage? initialMessage, void onMessageSent(ChatMessage)?, ChatThreadController? controller, Widget messageHeaderBuilder(BuildContext, MeshDocument, MeshElement)?, Widget waitingForParticipantsBuilder(BuildContext, List<String> )?, Widget attachmentBuilder(BuildContext context, FileAttachment upload)?, ValueChanged<FileAttachment> ? onAttachmentOpen, ValueChanged<FileAttachment> ? onAttachmentRemoved, Widget fileInThreadBuilder(BuildContext context, String path)?, Widget chatInputBoxBuilder(BuildContext context, Widget chatBox)?, ChatThreadCustomInputBuilder? customInputBuilder, FutureOr<void> openFile(String path)?, FileDropOverlayBuilder? fileDropOverlayBuilder, Widget toolsBuilder(BuildContext, ChatThreadController, ChatThreadSnapshot)?, Widget? inputPlaceholder, String? emptyStateTitle, String? emptyStateDescription, Widget? emptyState, String? agentName, FutureOr<void> onVisibleMessagesEmpty()?, bool initialShowCompletedToolCalls = false, bool shouldShowAuthorNames = true, EditableTextContextMenuBuilder? inputContextMenuBuilder, TapRegionCallback? inputOnPressedOutside, ThreadStorageSaveSurfacePresenter? mobileStorageSaveSurfacePresenter, double? mobileUnderHeaderContentPadding}) -
const
Properties
- agentName → String?
-
final
- attachmentBuilder → Widget Function(BuildContext context, FileAttachment upload)?
-
final
- chatInputBoxBuilder → Widget Function(BuildContext context, Widget chatBox)?
-
final
-
composerKey
→ GlobalKey<
State< ?StatefulWidget> > -
final
- controller → ChatThreadController?
-
final
- customInputBuilder → ChatThreadCustomInputBuilder?
-
final
- emptyState → Widget?
-
final
- emptyStateDescription → String?
-
final
- emptyStateTitle → String?
-
final
- fileDropOverlayBuilder → FileDropOverlayBuilder?
-
final
- fileInThreadBuilder → Widget Function(BuildContext context, String path)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeLocalParticipant → bool
-
final
- initialMessage → ChatMessage?
-
final
- initialShowCompletedToolCalls → bool
-
final
- inputContextMenuBuilder → EditableTextContextMenuBuilder?
-
final
- inputOnPressedOutside → TapRegionCallback?
-
final
- inputPlaceholder → Widget?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- messageHeaderBuilder → Widget Function(BuildContext, MeshDocument, MeshElement)?
-
final
- mobileStorageSaveSurfacePresenter → ThreadStorageSaveSurfacePresenter?
-
final
- mobileUnderHeaderContentPadding → double?
-
final
-
onAttachmentOpen
→ ValueChanged<
FileAttachment> ? -
final
-
onAttachmentRemoved
→ ValueChanged<
FileAttachment> ? -
final
- onMessageSent → void Function(ChatMessage)?
-
final
-
onVisibleMessagesEmpty
→ FutureOr<
void> Function()? -
final
-
openFile
→ FutureOr<
void> Function(String path)? -
final
-
participantNames
→ List<
String> ? -
final
-
participants
→ List<
Participant> ? -
final
- path → String
-
final
- room → RoomClient
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldShowAuthorNames → bool
-
final
-
final
- startChatCentered → bool
-
final
- toolsBuilder → Widget Function(BuildContext, ChatThreadController, ChatThreadSnapshot)?
-
final
-
waitingForParticipantsBuilder
→ Widget Function(BuildContext, List<
String> )? -
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited