ChatThreadController class

Inheritance

Constructors

ChatThreadController({required RoomClient? room})

Properties

attachmentUploads List<FileAttachment>
no setter
clientToolkitDescriptions List<ClientToolkitDescription>
no setter
clientToolkits List<Toolkit>
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
listening bool
getter/setter pair
notifyOnSend bool
getter/setter pair
outboundStatus OutboundMessageStatusQueue
final
pendingAgentMessages List<PendingAgentMessage>
no setter
room → RoomClient?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedMcpConnectors List<Connector>
no setter
text String
no setter
textFieldController TextEditingController
final
threadScrollController ScrollController
final

Methods

addClientToolkit(Toolkit toolkit) → void
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
attachFile(String path, {String? mimeType, String? displayName}) FileAttachment
cancel(String path, MeshDocument thread, {bool useAgentMessages = false, String? turnId, String? participantName}) Future<void>
cancelPendingSend(String threadPath) → void
clear() → void
clearMcpConnectorSelections({bool notify = true}) → void
clearPendingAgentMessages() → void
clearPendingAgentMessagesForThread(String threadPath) → void
clearThread(String path, MeshDocument thread, {bool useAgentMessages = false, String? participantName}) Future<void>
dispose() → void
Discards any resources used by the object.
override
executeClientToolCall(AgentClientToolCallRequested request) Future<Content>
getAgentParticipants(MeshDocument document, {String? participantName}) Iterable<RemoteParticipant>
getOfflineParticipants(MeshDocument document) Iterable<String>
getOnlineParticipants(MeshDocument document) Iterable<Participant>
getParticipantNames(MeshDocument document) Iterable<String>
handleAgentMessage(AgentMessage message) → void
handleAgentMessagePayload(Map<String, dynamic> payload) → void
hasPendingSendWait(String threadPath) bool
insertMessage({required MeshDocument thread, required ChatMessage message}) → void
isMcpConnectorSelected(Connector connector) bool
isToolkitEnabled(String toolkitName) bool
markPendingAgentMessage(PendingAgentMessage message) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
pendingAgentMessagesForPath(String path) List<PendingAgentMessage>
removeClientToolkit(String toolkitName) → void
removeFileUpload(FileAttachment upload) → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
resetThreadScrollPosition() → void
scrollThreadToBottom({bool animated = true}) → void
send({required MeshDocument thread, required String path, required ChatMessage message, String messageType = "chat", String? remoteStoreParticipantName, bool storeLocally = true, bool useAgentMessages = false, String? turnId, TurnMcpConfig? mcp, List<ClientToolkitDescription>? clientToolkits, AgentToolChoice? toolChoice, void onMessageSent(ChatMessage)?}) Future<void>
sendMessageToParticipant({required Participant participant, required String path, required ChatMessage message, String messageType = "chat", bool useAgentMessages = false, String? turnId, TurnMcpConfig? mcp, List<ClientToolkitDescription>? clientToolkits, AgentToolChoice? toolChoice, bool store = false}) Future<void>
setMcpConnectorSelected(Connector connector, bool selected) → void
toggleToolkit(String toolkitName) bool
toString() String
A string representation of this object.
inherited
uploadFile(String path, Stream<Uint8List> dataStream, int size, {String? mimeType}) Future<FileAttachment>
uploadFileDeferred(String path, Stream<Uint8List> dataStream, int size, {String? mimeType}) Future<FileAttachment>

Operators

operator ==(Object other) bool
The equality operator.
inherited