ChatThreadFeedImage class

Constructors

ChatThreadFeedImage({required String attachmentElementId, required String imageId, String? path, String? imageUri, String? mimeType, String? status, String? statusDetail, double? widthPx, double? heightPx})
const

Properties

attachmentElementId String
final
hashCode int
The hash code for this object.
no setterinherited
heightPx double?
final
imageId String
final
imageUri String?
final
mimeType String?
final
path String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final
statusDetail String?
final
widthPx double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited