ChatThreadInput class

Inheritance

Constructors

ChatThreadInput({Key? key, required Future<void> onSend(String, List<FileAttachment>), required ChatThreadController controller, RoomClient? room, bool autoFocus = true, Object? focusTrigger, bool sendEnabled = true, String? sendDisabledReason, bool readOnly = false, bool clearOnSend = true, Widget? placeholder, void onChanged(String, List<FileAttachment>)?, Widget attachmentBuilder(BuildContext context, FileAttachment upload)?, ValueChanged<FileAttachment>? onAttachmentOpen, ValueChanged<FileAttachment>? onAttachmentRemoved, Future<void> onFileDrop(String name, Stream<Uint8List> dataStream, int size)?, Widget? leading, Widget? trailing, Widget? header, Widget? footer, bool audioInputEnabled = false, bool automaticAudioTurnDetection = false, Future<void> onAudioRecordingStart()?, Future<void> onExternalAudioRecordingStart()?, Future<void> onExternalAudioRecordingStop()?, Future<void> onAudioChunk(Uint8List chunk, {required bool finalChunk})?, void onClear()?, void onInterrupt()?, void onCancelSend()?, String? sendPendingText, EditableTextContextMenuBuilder? contextMenuBuilder, TapRegionCallback? onPressedOutside, Object? tapRegionGroupId})
const

Properties

attachmentBuilder Widget Function(BuildContext context, FileAttachment upload)?
final
audioInputEnabled bool
final
autoFocus bool
final
automaticAudioTurnDetection bool
final
clearOnSend bool
final
contextMenuBuilder EditableTextContextMenuBuilder?
final
controller ChatThreadController
final
focusTrigger Object?
final
final
hashCode int
The hash code for this object.
no setterinherited
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading Widget?
final
onAttachmentOpen ValueChanged<FileAttachment>?
final
onAttachmentRemoved ValueChanged<FileAttachment>?
final
onAudioChunk Future<void> Function(Uint8List chunk, {required bool finalChunk})?
final
onAudioRecordingStart Future<void> Function()?
final
onCancelSend VoidCallback?
final
onChanged → void Function(String, List<FileAttachment>)?
final
onClear VoidCallback?
final
onExternalAudioRecordingStart Future<void> Function()?
final
onExternalAudioRecordingStop Future<void> Function()?
final
onFileDrop Future<void> Function(String name, Stream<Uint8List> dataStream, int size)?
final
onInterrupt VoidCallback?
final
onPressedOutside TapRegionCallback?
final
onSend Future<void> Function(String, List<FileAttachment>)
final
placeholder Widget?
final
readOnly bool
final
room → RoomClient?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendDisabledReason String?
final
sendEnabled bool
final
sendPendingText String?
final
tapRegionGroupId Object?
final
trailing Widget?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited