ChatThreadInputConfig class
Constructors
-
ChatThreadInputConfig({required ChatThreadController controller, required ChatThreadSnapshot snapshot, required Widget? placeholder, required bool sendEnabled, required String? sendDisabledReason, required bool readOnly, required Future<
void> onSend(String, List<FileAttachment> ), void onChanged(String, List<FileAttachment> )?, VoidCallback? onClear, VoidCallback? onInterrupt, VoidCallback? onCancelSend, String? sendPendingText, Widget attachmentBuilder(BuildContext context, FileAttachment upload)?, ValueChanged<FileAttachment> ? onAttachmentOpen, ValueChanged<FileAttachment> ? onAttachmentRemoved, Future<void> onFileDrop(String name, Stream<Uint8List> dataStream, int size)?, Widget? leading, Widget? trailing, Widget? header, bool audioInputEnabled = false, bool automaticAudioTurnDetection = false, Future<void> onAudioRecordingStart()?, Future<void> onExternalAudioRecordingStart()?, Future<void> onExternalAudioRecordingStop()?, Future<void> onAudioChunk(Uint8List chunk, {required bool finalChunk})?, EditableTextContextMenuBuilder? contextMenuBuilder, TapRegionCallback? onPressedOutside, Object? tapRegionGroupId, RoomClient? room}) -
const
Properties
- attachmentBuilder → Widget Function(BuildContext context, FileAttachment upload)?
-
final
- audioInputEnabled → bool
-
final
- automaticAudioTurnDetection → bool
-
final
- contextMenuBuilder → EditableTextContextMenuBuilder?
-
final
- controller → ChatThreadController
-
final
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Widget?
-
final
- leading → Widget?
-
final
-
onAttachmentOpen
→ ValueChanged<
FileAttachment> ? -
final
-
onAttachmentRemoved
→ ValueChanged<
FileAttachment> ? -
final
-
onAudioChunk
→ Future<
void> Function(Uint8List chunk, {required bool finalChunk})? -
final
-
onAudioRecordingStart
→ Future<
void> Function()? -
final
- onCancelSend → VoidCallback?
-
final
-
onChanged
→ void Function(String, List<
FileAttachment> )? -
final
- onClear → VoidCallback?
-
final
-
onExternalAudioRecordingStart
→ Future<
void> Function()? -
final
-
onExternalAudioRecordingStop
→ Future<
void> Function()? -
final
-
onFileDrop
→ Future<
void> Function(String name, Stream<Uint8List> dataStream, int size)? -
final
- onInterrupt → VoidCallback?
-
final
- onPressedOutside → TapRegionCallback?
-
final
-
onSend
→ Future<
void> Function(String, List<FileAttachment> ) -
final
- placeholder → Widget?
-
final
- readOnly → bool
-
final
- room → RoomClient?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendDisabledReason → String?
-
final
- sendEnabled → bool
-
final
- sendPendingText → String?
-
final
- snapshot → ChatThreadSnapshot
-
final
- tapRegionGroupId → Object?
-
final
- trailing → Widget?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited