ChatThreadMessageView class

Inheritance

Constructors

ChatThreadMessageView({Key? key, RoomClient? room, required bool mine, required bool isAgentMessage, required String? text, required String authorName, required DateTime createdAt, bool shouldShowHeader = true, Widget? header, List<Widget> attachmentWidgets = const [], Widget? trailing, VoidCallback? onDelete, Widget reactionActionBuilder(ShadContextMenuController controller)?, bool showReactionAction = false, VoidCallback? onReactFromMenu, ThreadStorageSaveSurfacePresenter? mobileStorageSaveSurfacePresenter, Color? bubbleColor, Color? bubbleBorderColor, bool useDefaultBubbleBorder = true, Color? textColor, bool selectable = true, bool showBubbleActions = true, VoidCallback? onTap})
const

Properties

attachmentWidgets List<Widget>
final
authorName String
final
bubbleBorderColor Color?
final
bubbleColor Color?
final
createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
final
isAgentMessage bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mine bool
final
mobileStorageSaveSurfacePresenter ThreadStorageSaveSurfacePresenter?
final
onDelete VoidCallback?
final
onReactFromMenu VoidCallback?
final
onTap VoidCallback?
final
reactionActionBuilder Widget Function(ShadContextMenuController controller)?
final
room → RoomClient?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectable bool
final
shouldShowHeader bool
final
showBubbleActions bool
final
showReactionAction bool
final
text String?
final
textColor Color?
final
trailing Widget?
final
useDefaultBubbleBorder bool
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited