ChatThreadStatusState class

Constructors

ChatThreadStatusState({String? text, DateTime? startedAt, String? mode, String? turnId, List<PendingAgentMessage> pendingMessages = const [], String? pendingItemId, int? totalBytes, int? linesAdded, int? linesRemoved, bool supportsAgentMessages = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hasStatus bool
no setter
linesAdded int?
final
linesRemoved int?
final
mode String?
final
pendingItemId String?
final
pendingMessages List<PendingAgentMessage>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedAt DateTime?
final
supportsAgentMessages bool
final
text String?
final
totalBytes int?
final
turnId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited