ChatThreadViewportBody class

Inheritance

Constructors

ChatThreadViewportBody({Key? key, required List<Widget> children, ScrollController? scrollController, bool bottomAlign = true, Widget? centerContent, double bottomSpacer = 0, Key? bottomSpacerKey, Duration bottomSpacerAnimationDuration = Duration.zero, Curve bottomSpacerAnimationCurve = Curves.easeOutCubic, List<Widget> overlays = const [], Object? tapRegionGroupId, double? mobileUnderHeaderContentPadding})
const

Properties

bottomAlign bool
final
bottomSpacer double
final
bottomSpacerAnimationCurve Curve
final
bottomSpacerAnimationDuration Duration
final
bottomSpacerKey Key?
final
centerContent Widget?
final
children List<Widget>
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mobileUnderHeaderContentPadding double?
final
overlays List<Widget>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController?
final
tapRegionGroupId Object?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ChatThreadViewportBody>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited