ClientResponseDialogTool class

Inheritance
  • Object
  • BaseTool
  • FunctionTool
  • ClientResponseDialogTool

Constructors

ClientResponseDialogTool({required BuildContext context, required String name, String? title, String? description, required Map<String, dynamic> inputSchema})

Properties

defs Map<String, dynamic>?
finalinherited
description String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
inputSchema Map<String, dynamic>
finalinherited
inputSpec → ToolContentSpec?
finalinherited
name String
finalinherited
final
outputSchema Map<String, dynamic>?
finalinherited
outputSpec → ToolContentSpec?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
finalinherited

Methods

execute(ToolContext context, Map<String, dynamic> arguments) Future<Content>
override
executeStream(ToolContext context, Map<String, dynamic> arguments) Stream<Content>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited