DatasetChatAudioFormat class

Constructors

DatasetChatAudioFormat({String type = 'audio/pcm', int? sampleRate = 24000, int? bitrate})
const

Properties

bitrate int?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int?
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Object? value) DatasetChatAudioFormat?