DatasetChatModelOption class
Constructors
-
DatasetChatModelOption({String? backend, required String provider, required String providerFriendlyName, required String model, String? modelFriendlyName, String? modelDescription, List<
String> modalities = const <String>['text'], List<String> availableVoices = const <String>[], String? defaultOutputVoice, DatasetChatAudioFormat? inputFormat, DatasetChatAudioFormat? outputFormat, String? turnDetection, List<String> realtimeProtocols = const <String>[], bool supportsAttachments = false, List<String> accepts = const <String>[], bool active = false}) -
const
Properties
-
accepts
→ List<
String> -
final
- active → bool
-
final
-
availableVoices
→ List<
String> -
final
- backend → String?
-
final
- defaultOutputVoice → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputFormat → DatasetChatAudioFormat?
-
final
- key → String
-
no setter
- label → String
-
no setter
-
modalities
→ List<
String> -
final
- model → String
-
final
- modelDescription → String?
-
final
- modelFriendlyName → String?
-
final
- outputFormat → DatasetChatAudioFormat?
-
final
- provider → String
-
final
- providerFriendlyName → String
-
final
-
realtimeProtocols
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsAttachments → bool
-
final
- turnDetection → String?
-
final
Methods
-
copyWith(
{bool? active, bool? supportsAttachments, List< String> ? accepts}) → DatasetChatModelOption -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited