DatasetThreadImage class

Constructors

DatasetThreadImage({String? uri, String? imageId, String? mimeType, String? status, String? statusDetail, double? width, double? height})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
height double?
final
imageId String?
final
mimeType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final
statusDetail String?
final
uri String?
final
width double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited