NewChatThread class

Inheritance

Constructors

NewChatThread({Key? key, required String agentName, required NewChatThreadBuilder builder, RoomClient? room, BaseChatClient? chatClient, bool disposeChatClient = false, ChatThreadController? controller, GlobalKey<State<StatefulWidget>>? composerKey, String toolkit = "chat", String tool = "new_thread", NewChatThreadToolsBuilder? toolsBuilder, String? selectedThreadPath, ValueChanged<String?>? onThreadPathChanged, void onThreadResolved(String? path, String? displayName)?, bool centerComposer = true, bool showCenteredComposerTitle = true, bool showUsageFooter = false, Widget? emptyState, Widget? inputPlaceholder, EditableTextContextMenuBuilder? inputContextMenuBuilder, TapRegionCallback? inputOnPressedOutside, ValueChanged<FileAttachment>? onAttachmentOpen, ValueChanged<FileAttachment>? onAttachmentRemoved, FileDropOverlayBuilder? fileDropOverlayBuilder, DatasetChatModelController? modelController, ChatThreadCustomInputBuilder? customInputBuilder, NewChatThreadWrapperBuilder? newThreadWrapperBuilder})
const

Properties

agentName String
final
builder NewChatThreadBuilder
final
centerComposer bool
final
chatClient → BaseChatClient?
final
composerKey GlobalKey<State<StatefulWidget>>?
final
controller ChatThreadController?
final
customInputBuilder ChatThreadCustomInputBuilder?
final
disposeChatClient bool
final
emptyState Widget?
final
fileDropOverlayBuilder FileDropOverlayBuilder?
final
hashCode int
The hash code for this object.
no setterinherited
inputContextMenuBuilder EditableTextContextMenuBuilder?
final
inputOnPressedOutside TapRegionCallback?
final
inputPlaceholder Widget?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
modelController DatasetChatModelController?
final
newThreadWrapperBuilder NewChatThreadWrapperBuilder?
final
onAttachmentOpen ValueChanged<FileAttachment>?
final
onAttachmentRemoved ValueChanged<FileAttachment>?
final
onThreadPathChanged ValueChanged<String?>?
final
onThreadResolved → void Function(String? path, String? displayName)?
final
room → RoomClient?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedThreadPath String?
final
showCenteredComposerTitle bool
final
showUsageFooter bool
final
tool String
final
toolkit String
final
toolsBuilder NewChatThreadToolsBuilder?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<NewChatThread>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited