ChatThreadListView class

Inheritance

Constructors

ChatThreadListView({Key? key, required RoomClient? room, BaseChatClient? chatClient, required String threadListPath, required String? selectedThreadPath, required ValueChanged<String?> onSelectedThreadPathChanged, void onSelectedThreadResolved(String? path, String? displayName)?, String? selectedThreadDisplayName, String? agentName, bool showCreateItem = true, int newThreadResetVersion = 0})
const

Properties

agentName String?
final
chatClient → BaseChatClient?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
newThreadResetVersion int
final
onSelectedThreadPathChanged ValueChanged<String?>
final
onSelectedThreadResolved → void Function(String? path, String? displayName)?
final
room → RoomClient?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedThreadDisplayName String?
final
selectedThreadPath String?
final
showCreateItem bool
final
threadListPath String
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ChatThreadListView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited