ToolCallEntryDisplay class

Constructors

ToolCallEntryDisplay({required ToolCallHeadline headline, required List<String> detailLines, bool detailsTruncated = false})
const

Properties

detailLines List<String>
final
detailsTruncated bool
final
hashCode int
The hash code for this object.
no setterinherited
headline ToolCallHeadline
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited