ToolCallHeadline class

Constructors

ToolCallHeadline({required String action, String rest = '', String? detailLanguageOrFilename, int? linesAdded, int? linesRemoved})
const

Properties

action String
final
detailLanguageOrFilename String?
final
hashCode int
The hash code for this object.
no setterinherited
linesAdded int?
final
linesRemoved int?
final
rest String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited