CodeEditorStyle class

Constructors

CodeEditorStyle({Color? backgroundColor, Color? cursorColor, String? fontFamily, double? fontSize, Color? textColor, CodeHighlightTheme? codeTheme})
const

Properties

backgroundColor Color?
final
codeTheme CodeHighlightTheme?
final
cursorColor Color?
final
fontFamily String?
final
fontSize double?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor Color?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited