CodeLineEditingController class
- Inheritance
-
- Object
- ChangeNotifier
- CodeLineEditingController
- Implementers
Constructors
- CodeLineEditingController({CodeLines? codeLines})
- CodeLineEditingController.fromText(String text)
-
factory
Properties
- delegate → PlatformCodeLineEditingController
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedText → String
-
no setter
- selection ↔ TextSelection
-
getter/setter pair
- text ↔ String
-
getter/setter pair
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
copy(
) → Future< void> -
cut(
) → void -
dispose(
) → void -
Discards any resources used by the object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
paste(
) → void -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
selectAll(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited