data_grid/swayze_math/src/matrix_map library

Classes

MatrixMap<T>
A data structure that organizes items of T in a 2d map with int keys.
MatrixMapIterableResult<T>
Holds the value and position of an item in a MatrixMapReadOnly.
MatrixMapReadOnly<T>
A read only interface for instances of MatrixMap

Typedefs

MatrixMapIterator<T> = void Function(T item, int colIndex, int rowIndex)
A function signature to iterate on a MatrixMap of type T
MaybeMatrixMapIterator<T> = void Function(T? item, int colIndex, int rowIndex)
A function signature to iterate on a MatrixMap of type T