MatrixMapIterableResult<T> class

Holds the value and position of an item in a MatrixMapReadOnly.

Constructors

MatrixMapIterableResult({required IntVector2 position, required T value})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
position IntVector2
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited