Range class
- Implementers
- Annotations
Properties
- end → int
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isNil → bool
-
If this is a range with no elements
no setter
- isNotNil → bool
-
If this is a range with any element
no setter
-
iterable
→ Iterable<
int> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → int
-
final
Methods
-
clone(
) → Range - Create a identical range
-
contains(
Object? position) → bool - Verifies if a given position is contained within the range
-
containsRange(
Range otherRange) → bool -
Defines if this range contains
otherRangeentirely -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
overlaps(
Range otherRange) → bool -
Defines if this range overlaps
otherRange -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator &(
Range otherRange) → Range - Gets the intersection between two ranges, range nil if they don't intersect
-
operator +(
Range otherRange) → RangeCompactList - Performs a union with another range merge if overlaps
-
operator -(
Range otherRange) → RangeCompactList -
Return all the elements on the this range that is not present
on the
otherRange. -
operator ==(
Object other) → bool -
The equality operator.
override
-
operator |(
Range otherRange) → Range - Stretches and merges two ranges including all possible non covered spaces between them