RangeCompactList class

A list of ranges that keeps with the smallest possible size (no overlaps between its members)

Inheritance
Annotations

Constructors

RangeCompactList()

Properties

first Range
The first element.
no setterinherited
hashCode int
The hash code for this object.
no setteroverride
isEmpty bool
Whether this collection has no elements.
no setterinherited
isNotEmpty bool
Whether this collection has at least one element.
no setterinherited
iterator Iterator<Range>
A new Iterator that allows iterating the elements of this Iterable.
no setteroverride
last Range
The last element.
no setterinherited
length int
The number of elements in this Iterable.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
single Range
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

add(Range newItem) → void
Adds an newItem to the list by merging with existing items that overlaps with it
any(bool test(Range otherRange)) bool
Checks whether any element of this iterable satisfies test.
inherited
cast<R>() Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
clone() RangeCompactList
contains(Object? element) bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) Range
Returns the indexth element.
inherited
every(bool test(Range otherRange)) bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(Range element)) Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(Range otherRange), {Range orElse()?}) Range
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, Range element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<Range> other) Iterable<Range>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(Range newItem)) → void
Invokes action on each element of this iterable in iteration order.
inherited
join([String separator = ""]) String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(Range otherRange), {Range orElse()?}) Range
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(Range e)) Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(Range combine(Range value, Range element)) Range
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
singleWhere(bool test(Range otherRange), {Range orElse()?}) Range
The single element that satisfies test.
inherited
skip(int count) Iterable<Range>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(Range otherRange)) Iterable<Range>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) Iterable<Range>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(Range otherRange)) Iterable<Range>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) List<Range>
Creates a List containing the elements of this Iterable.
inherited
toSet() Set<Range>
Creates a Set containing the same elements as this iterable.
inherited
toString() String
Returns a string representation of (some of) the elements of this.
override
where(bool test(Range otherRange)) Iterable<Range>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator &(Range otherRange) RangeCompactList
operator +(Range otherRange) RangeCompactList
Union this RangeList with another range
operator ==(Object other) bool
The equality operator.
override