data_grid/swayze/src/helpers/scroll/auto_scroll library

Classes

AutoScrollDragScrollData
DragScrollData for automatic scroll from a drag gesture.
DoNotScrollDragScrollData
DragScrollData for when there is not supposed to have any scroll given a drag gesture.
DragScrollData
A base class for classes that describe the behavior of scroll given a drag gesture.
ResetScrollDragScrollData
DragScrollData for when a drag gesture may cause the scroll to reset to the start of the table in the given axis.

Constants

kAutoScrollTriggerThreshold → const int

Functions

getHorizontalDragScrollData({required double displacement, required double globalOffset, required double localOffset, required double gestureOriginOffset, required double viewportExtent, required double screenWidth, required double frozenExtent}) DragScrollData
Given the pointer local and global offsets return DragScrollData for the horizontal axis.
getVerticalDragScrollData({required double displacement, required double globalOffset, required double localOffset, required double gestureOriginOffset, required double viewportExtent, required double screenHeight, required double frozenExtent, required double positionPixel, required ScrollingData scrollingData}) DragScrollData
Given the pointer local and global offsets return DragScrollData for the vertical axis.