DragScrollData class abstract

A base class for classes that describe the behavior of scroll given a drag gesture.

Used by TableBodyGestureDetector and HeaderGestureDetector.

See the subclasses:

Implementers
Annotations

Constructors

DragScrollData()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited