ResetScrollDragScrollData class

DragScrollData for when a drag gesture may cause the scroll to reset to the start of the table in the given axis.

Implemented types

Constructors

ResetScrollDragScrollData()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited