InternalScope<CellDataType extends SwayzeCellData> class abstract

A scope to make internal state and context accessible all internal elements on swayze.

See also:

  • SliverSwayzeTable the widget created by the package-user that adds this scope into the widget tree.
Implementers

Constructors

InternalScope()

Properties

cellDelegate CellDelegate<CellDataType>
no setter
controller SwayzeController
The main controller specified to this table.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style SwayzeStyle
The style specified to this table.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) InternalScope<SwayzeCellData>
Access the scope from a context subtree. Should be called by descendants of InternalScopeProvider.