SwayzeTableStatus class

Constructors

SwayzeTableStatus({required bool isSql, required bool isLoadingMetadata, required bool isLoadingRows, required int? rowCount, required int loadedRowCount, required int loadedByteCount, required int skippedBinaryCount, required int? statementRowsAffected})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
isLoading bool
no setter
isLoadingMetadata bool
final
isLoadingRows bool
final
isSql bool
final
loadedByteCount int
final
loadedRowCount int
final
primaryText String
no setter
rowCount int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryText String?
no setter
skippedBinaryCount int
final
statementRowsAffected int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override