CodePreviewEditorConfiguration class

Constructors

CodePreviewEditorConfiguration({required String filename, required CodeLineEditingController controller, required FocusNode focusNode, required bool readOnly, required EdgeInsetsGeometry padding, required CodeEditorStyle style, required ValueChanged<String> onChanged})
const

Properties

controller CodeLineEditingController
final
filename String
final
focusNode FocusNode
final
hashCode int
The hash code for this object.
no setterinherited
onChanged ValueChanged<String>
final
padding EdgeInsetsGeometry
final
readOnly bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style CodeEditorStyle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited