JsonMetadataEditingController class

Inheritance

Constructors

JsonMetadataEditingController({Map<String, dynamic> value = const <String, dynamic>{}})

Properties

delegate → PlatformCodeLineEditingController
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedText String
no setterinherited
selection TextSelection
getter/setter pairinherited
text String
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
copy() Future<void>
inherited
cut() → void
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
parse({String label = 'Metadata'}) Map<String, dynamic>
paste() → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
selectAll() → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited