SelectSubjectsController class

Inheritance

Constructors

SelectSubjectsController({required Map<String, AccessSubject> subjectsByKey, required bool allowNewUserEmail, Future<AccessSubject?> resolveSubject(String email)?, bool isAllowedSubject(AccessSubject subject)?, List<String> initialValue = const []})

Properties

allowNewUserEmail bool
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isAllowedSubject bool Function(AccessSubject subject)?
final
resolveSubject Future<AccessSubject?> Function(String email)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subjectsByKey Map<String, AccessSubject>
final
value List<String>
The current value stored in this notifier.
getter/setter pairinherited

Methods

add(String item) FutureOr<bool>
inherited
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
canAddItem(String item) FutureOr<bool>
override
clear() → void
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
remove(String item) → void
inherited
removeLast() → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited