data_grid/swayze/helpers library

Functions

computeHeaderAutoFitExtent<CellDataType extends SwayzeCellData>({required BuildContext context, required Axis axis, required int headerPosition, required SwayzeTableDataController<SwayzeController> tableDataController, required CellDelegate<CellDataType> cellDelegate, required MatrixMapReadOnly<CellDataType> cellMatrix, required SwayzeStyle style, required String headerLabel}) Future<double?>
computeHeaderAutoFitExtents<CellDataType extends SwayzeCellData>({required BuildContext context, required Axis axis, required Iterable<int> headerPositions, required SwayzeTableDataController<SwayzeController> tableDataController, required CellDelegate<CellDataType> cellDelegate, required MatrixMapReadOnly<CellDataType> cellMatrix, required SwayzeStyle style, required String headerLabelFor(int headerPosition)}) Future<Map<int, double>>
createColorFromHEX(String hexString) Color
Return a Color from a Hex string.
createHeaderAutoFitMeasurementRequest({required String label, required SwayzeStyle style}) SwayzeAutoFitMeasurementRequest
createHexStringFromColor(Color color) String
Returns a string HEX color prefixed with "#".
generateLabelForCoordinate(IntVector2 coordinate) String
Generates a label that represents a coordinate composed by the results of generateLabelForIndex for each axis concatenated.
generateLabelForIndex(Axis axis, int index) String
Generates a header label given an axis and a header index.
maxAutoFitExtentForAxis(SwayzeStyle style, Axis axis) double?
measureAutoFitLayouts(BuildContext context, List<SwayzeAutoFitMeasurementRequest> requests) Future<List<Size>>
minimumResizableExtentForAxis(Axis axis) double