FileBrowserPathViewModel class

Constructors

FileBrowserPathViewModel({required String path, required List<String> segments, required int currentSelectionCount, required String rootLabel, required VoidCallback onRootPressed, required void onSegmentPressed(int index)})
const

Properties

currentSelectionCount int
final
hashCode int
The hash code for this object.
no setterinherited
onRootPressed VoidCallback
final
onSegmentPressed → void Function(int index)
final
path String
final
rootLabel String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited