FileBrowserRowViewModel class

Constructors

FileBrowserRowViewModel({required StorageEntry entry, required String fullPath, required String displayName, required bool selected, required bool canActivate, required VoidCallback onPressed, required bool canToggleSelection, VoidCallback? onToggleSelection})
const

Properties

canActivate bool
final
canToggleSelection bool
final
displayName String
final
entry → StorageEntry
final
fullPath String
final
hashCode int
The hash code for this object.
no setterinherited
onPressed VoidCallback
final
onToggleSelection VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited