ThreadTypographyOverride class

Inheritance

Constructors

ThreadTypographyOverride({Key? key, required Widget child, String? textFontFamily, String? codeFontFamily, double? threadParagraphBaseFontSize, double? threadParagraphLineHeight, double? narrowDesktopParagraphBaseFontSize, EdgeInsets? bubbleContentPadding, double? threadFeedItemSpacing, bool useThreadAttachmentStyle = false, bool normalizeParticipantDisplayName = false, bool showInlineDisclosureCue = false, bool useDesktopAuthorHeaderAtNarrowWidths = false, Color? mineBubbleColor, Color? mineBubbleTextColor, Color? mineBubbleLinkColor, Color? otherHumanBubbleColor, Color? otherHumanBubbleTextColor, Color? agentBubbleColor, Color? agentBubbleBorderColor, Color? linkColor, Color? attachmentSurfaceColor, Color? attachmentBorderColor, Color? attachmentIconColor, Color? attachmentActionColor, Color? attachmentHoverSurfaceColor, List<BoxShadow>? attachmentHoverShadows, bool alignAttachmentEdgesWithBubbles = false, ThreadAttachmentIconBuilder? attachmentIconBuilder, ThreadAttachmentActionIconBuilder? attachmentActionIconBuilder, Color? codeBlockSurfaceColor, Color? codeBlockHeaderSurfaceColor, Color? codeBlockBorderColor, Color? codeBlockTextColor, Color? codeBlockHeaderTextColor, Map<String, TextStyle>? codeBlockHighlightTheme, double? codeBlockFontSize, double? codeBlockLineHeight, bool codeBlockUseTextFontSize = false, bool codeBlockWrapLines = false, double? codeBlockHeaderFontSize, double? codeBlockActionIconSize, double? codeBlockActionButtonSize, Color? inlineCodeTextColor, Color? inlineCodeBackgroundColor, bool inlineCodeHorizontalPadding = false, Color? threadErrorSurfaceColor, Color? threadErrorTextColor, Color? markdownHorizontalRuleColor, Color? markdownBlockquoteSideColor, Color? markdownBlockquoteBackgroundColor, bool markdownSuppressHeadingDividers = false, ThreadMarkdownHeadingPaddingResolver? markdownHeadingPaddingResolver, ThreadMarkdownHeadingStyleResolver? markdownHeadingStyleResolver, ThreadMarkdownTextTransformer? markdownTextTransformer, ThreadMarkdownLinkHandler? markdownLinkHandler})
const

Properties

agentBubbleBorderColor Color?
final
agentBubbleColor Color?
final
alignAttachmentEdgesWithBubbles bool
final
attachmentActionColor Color?
final
attachmentActionIconBuilder ThreadAttachmentActionIconBuilder?
final
attachmentBorderColor Color?
final
attachmentHoverShadows List<BoxShadow>?
final
attachmentHoverSurfaceColor Color?
final
attachmentIconBuilder ThreadAttachmentIconBuilder?
final
attachmentIconColor Color?
final
attachmentSurfaceColor Color?
final
bubbleContentPadding EdgeInsets?
final
child Widget
The widget below this widget in the tree.
finalinherited
codeBlockActionButtonSize double?
final
codeBlockActionIconSize double?
final
codeBlockBorderColor Color?
final
codeBlockFontSize double?
final
codeBlockHeaderFontSize double?
final
codeBlockHeaderSurfaceColor Color?
final
codeBlockHeaderTextColor Color?
final
codeBlockHighlightTheme Map<String, TextStyle>?
final
codeBlockLineHeight double?
final
codeBlockSurfaceColor Color?
final
codeBlockTextColor Color?
final
codeBlockUseTextFontSize bool
final
codeBlockWrapLines bool
final
codeFontFamily String?
final
hashCode int
The hash code for this object.
no setterinherited
inlineCodeBackgroundColor Color?
final
inlineCodeHorizontalPadding bool
final
inlineCodeTextColor Color?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
linkColor Color?
final
markdownBlockquoteBackgroundColor Color?
final
markdownBlockquoteSideColor Color?
final
markdownHeadingPaddingResolver ThreadMarkdownHeadingPaddingResolver?
final
markdownHeadingStyleResolver ThreadMarkdownHeadingStyleResolver?
final
markdownHorizontalRuleColor Color?
final
markdownLinkHandler ThreadMarkdownLinkHandler?
final
markdownSuppressHeadingDividers bool
final
markdownTextTransformer ThreadMarkdownTextTransformer?
final
mineBubbleColor Color?
final
mineBubbleLinkColor Color?
final
mineBubbleTextColor Color?
final
narrowDesktopParagraphBaseFontSize double?
final
normalizeParticipantDisplayName bool
final
otherHumanBubbleColor Color?
final
otherHumanBubbleTextColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showInlineDisclosureCue bool
final
textFontFamily String?
final
threadErrorSurfaceColor Color?
final
threadErrorTextColor Color?
final
threadFeedItemSpacing double?
final
threadParagraphBaseFontSize double?
final
threadParagraphLineHeight double?
final
useDesktopAuthorHeaderAtNarrowWidths bool
final
useThreadAttachmentStyle bool
final

Methods

createElement() InheritedElement
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
updateShouldNotify(covariant ThreadTypographyOverride oldWidget) bool
Whether the framework should notify widgets that inherit from this widget.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

alignAttachmentEdgesWithBubblesOf(BuildContext context) bool
codeBlockUseTextFontSizeOf(BuildContext context) bool
codeBlockWrapLinesOf(BuildContext context) bool
inlineCodeHorizontalPaddingOf(BuildContext context) bool
markdownSuppressHeadingDividersOf(BuildContext context) bool
maybeAgentBubbleBorderColorOf(BuildContext context) Color?
maybeAgentBubbleColorOf(BuildContext context) Color?
maybeAttachmentActionColorOf(BuildContext context) Color?
maybeAttachmentActionIconBuilderOf(BuildContext context) ThreadAttachmentActionIconBuilder?
maybeAttachmentBorderColorOf(BuildContext context) Color?
maybeAttachmentHoverShadowsOf(BuildContext context) List<BoxShadow>?
maybeAttachmentHoverSurfaceColorOf(BuildContext context) Color?
maybeAttachmentIconBuilderOf(BuildContext context) ThreadAttachmentIconBuilder?
maybeAttachmentIconColorOf(BuildContext context) Color?
maybeAttachmentSurfaceColorOf(BuildContext context) Color?
maybeBubbleContentPaddingOf(BuildContext context) EdgeInsets?
maybeCodeBlockActionButtonSizeOf(BuildContext context) double?
maybeCodeBlockActionIconSizeOf(BuildContext context) double?
maybeCodeBlockBorderColorOf(BuildContext context) Color?
maybeCodeBlockFontSizeOf(BuildContext context) double?
maybeCodeBlockHeaderFontSizeOf(BuildContext context) double?
maybeCodeBlockHeaderSurfaceColorOf(BuildContext context) Color?
maybeCodeBlockHeaderTextColorOf(BuildContext context) Color?
maybeCodeBlockHighlightThemeOf(BuildContext context) Map<String, TextStyle>?
maybeCodeBlockLineHeightOf(BuildContext context) double?
maybeCodeBlockSurfaceColorOf(BuildContext context) Color?
maybeCodeBlockTextColorOf(BuildContext context) Color?
maybeCodeFontFamilyOf(BuildContext context) String?
maybeInlineCodeBackgroundColorOf(BuildContext context) Color?
maybeInlineCodeTextColorOf(BuildContext context) Color?
maybeLinkColorOf(BuildContext context) Color?
maybeMarkdownBlockquoteBackgroundColorOf(BuildContext context) Color?
maybeMarkdownBlockquoteSideColorOf(BuildContext context) Color?
maybeMarkdownHeadingPaddingOf(BuildContext context, String tag) EdgeInsets?
maybeMarkdownHeadingStyleOf(BuildContext context, String tag, TextStyle defaultStyle) TextStyle?
maybeMarkdownHorizontalRuleColorOf(BuildContext context) Color?
maybeMarkdownLinkHandlerOf(BuildContext context) ThreadMarkdownLinkHandler?
maybeMarkdownTextTransformerOf(BuildContext context) ThreadMarkdownTextTransformer?
maybeMineBubbleColorOf(BuildContext context) Color?
maybeMineBubbleLinkColorOf(BuildContext context) Color?
maybeMineBubbleTextColorOf(BuildContext context) Color?
maybeNarrowDesktopParagraphBaseFontSizeOf(BuildContext context) double?
maybeOf(BuildContext context) ThreadTypographyOverride?
maybeOtherHumanBubbleColorOf(BuildContext context) Color?
maybeOtherHumanBubbleTextColorOf(BuildContext context) Color?
maybeTextFontFamilyOf(BuildContext context) String?
maybeThreadErrorSurfaceColorOf(BuildContext context) Color?
maybeThreadErrorTextColorOf(BuildContext context) Color?
maybeThreadFeedItemSpacingOf(BuildContext context) double?
maybeThreadParagraphBaseFontSizeOf(BuildContext context) double?
maybeThreadParagraphLineHeightOf(BuildContext context) double?
normalizeParticipantDisplayNameOf(BuildContext context) bool
showInlineDisclosureCueOf(BuildContext context) bool
useDesktopAuthorHeaderAtNarrowWidthsOf(BuildContext context) bool
useThreadAttachmentStyleOf(BuildContext context) bool