DisplayDocument class

Inheritance
  • Object
  • BaseTool
  • FunctionTool
  • DisplayDocument

Constructors

DisplayDocument({required BuildContext context, required void opener(String path), String name = "display_document", String? description = "display a document to the user", String? title = "display document"})

Properties

context BuildContext
final
defs Map<String, dynamic>?
finalinherited
description String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
inputSchema Map<String, dynamic>
finalinherited
inputSpec → ToolContentSpec?
finalinherited
name String
finalinherited
opener → void Function(String path)
final
outputSchema Map<String, dynamic>?
finalinherited
outputSpec → ToolContentSpec?
finalinherited
pricing String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportsContext bool
finalinherited
thumbnailUrl String?
finalinherited
title String?
finalinherited

Methods

execute(ToolContext context, Map<String, dynamic> arguments) Future<Content>
override
executeStream(ToolContext context, Map<String, dynamic> arguments) Stream<Content>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited