CoordinatedShadContextMenu class

Inheritance

Constructors

CoordinatedShadContextMenu({Key? key, required Widget child, required List<Widget> items, ShadAnchorBase? anchor, bool? visible, BoxConstraints? constraints, ValueChanged<bool>? onHoverArea, EdgeInsetsGeometry? padding, Object? groupId, List<BoxShadow>? shadows, ShadDecoration? decoration, ImageFilter? filter, ShadContextMenuController? controller, TapRegionCallback? onTapOutside, TapRegionCallback? onTapInside, TapRegionUpCallback? onTapUpInside, TapRegionUpCallback? onTapUpOutside, Duration? popoverReverseDuration, ShadMenuHorizontalPosition horizontalPosition = ShadMenuHorizontalPosition.automatic, ShadMenuVerticalPosition verticalPosition = ShadMenuVerticalPosition.automatic, BuildContext? boundaryContext, double? estimatedMenuWidth, double? estimatedMenuHeight, double anchorGap = 8, double viewportVerticalSplit = 2 / 3, double viewportEdgePadding = 12, bool centerHorizontallyInBoundary = false})
const

Properties

anchor → ShadAnchorBase?
final
anchorGap double
final
boundaryContext BuildContext?
final
centerHorizontallyInBoundary bool
final
child Widget
final
constraints BoxConstraints?
final
controller → ShadContextMenuController?
final
decoration → ShadDecoration?
final
estimatedMenuHeight double?
final
estimatedMenuWidth double?
final
filter ImageFilter?
final
groupId Object?
final
hashCode int
The hash code for this object.
no setterinherited
horizontalPosition ShadMenuHorizontalPosition
final
items List<Widget>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onHoverArea ValueChanged<bool>?
final
onTapInside TapRegionCallback?
final
onTapOutside TapRegionCallback?
final
onTapUpInside TapRegionUpCallback?
final
onTapUpOutside TapRegionUpCallback?
final
padding EdgeInsetsGeometry?
final
popoverReverseDuration Duration?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadows List<BoxShadow>?
final
verticalPosition ShadMenuVerticalPosition
final
viewportEdgePadding double
final
viewportVerticalSplit double
final
visible bool?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CoordinatedShadContextMenu>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited