ShadMobileFlowDialogSurface class

Inheritance

Constructors

ShadMobileFlowDialogSurface({Key? key, required BoxConstraints? constraints, required Color backgroundColor, required BorderRadius radius, required BoxBorder? border, required List<BoxShadow>? shadows, required EdgeInsetsGeometry padding, required Widget? title, required Widget? description, required Widget? body, required List<Widget> actions, required double gap, required double actionsGap, required ShadMobileFlowDialogBodyBehavior bodyBehavior, required bool usesHorizontalActionRow, required double keyboardInset, required bool hideActionsWhenKeyboardVisible, EdgeInsets scrollableBodyPadding = shadDialogScrollableListPadding, double contentSectionGap = shadMobileFlowDialogContentSectionGap})
const

Properties

actions List<Widget>
final
actionsGap double
final
backgroundColor Color
final
body Widget?
final
bodyBehavior ShadMobileFlowDialogBodyBehavior
final
border BoxBorder?
final
constraints BoxConstraints?
final
contentSectionGap double
final
description Widget?
final
gap double
final
hashCode int
The hash code for this object.
no setterinherited
hideActionsWhenKeyboardVisible bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardInset double
final
padding EdgeInsetsGeometry
final
radius BorderRadius
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollableBodyPadding EdgeInsets
final
shadows List<BoxShadow>?
final
title Widget?
final
usesHorizontalActionRow bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ShadMobileFlowDialogSurface>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited