VoiceAgentDisconnectedState class

Constructors

VoiceAgentDisconnectedState({required String title, required String description, required double availableWidth, required bool transcribe, required bool showDisconnectedAction, required bool allowToggleTranscribe, required bool pinActionToMobileFooter, required Future<void> onStartSessionPressed(), required ValueChanged<bool>? onTranscribeChanged})
const

Properties

allowToggleTranscribe bool
final
availableWidth double
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
onStartSessionPressed Future<void> Function()
final
onTranscribeChanged ValueChanged<bool>?
final
pinActionToMobileFooter bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDisconnectedAction bool
final
title String
final
transcribe bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited