ChatThreadMessages class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ChatThreadMessages
Constructors
-
ChatThreadMessages({Key? key, required RoomClient? room, required String path, required ScrollController scrollController, Object? composerTapRegionGroupId, required List<
MeshElement> messages, required List<Participant> online, required bool showCompletedToolCalls, bool shouldShowAuthorNames = true, bool startChatCentered = false, bool showTyping = false, bool showListening = false, String? threadStatus, DateTime? threadStatusStartedAt, String? threadStatusMode, int? threadStatusTotalBytes, int? threadStatusLinesAdded, int? threadStatusLinesRemoved, List<PendingAgentMessage> pendingMessages = const [], String? pendingItemId, void onCancel()?, String? agentName, Widget messageHeaderBuilder(BuildContext, MeshDocument, MeshElement)?, Widget fileInThreadBuilder(BuildContext context, String path)?, FutureOr<void> openFile(String path)?, Map<String, MessageBuilder> ? messageBuilders, String? emptyStateTitle, String? emptyStateDescription, Widget? emptyState, ValueChanged<bool> ? onShowCompletedToolCallsChanged, ThreadStorageSaveSurfacePresenter? mobileStorageSaveSurfacePresenter, double? mobileUnderHeaderContentPadding}) -
const
Properties
- agentName → String?
-
final
- composerTapRegionGroupId → Object?
-
final
- emptyState → Widget?
-
final
- emptyStateDescription → String?
-
final
- emptyStateTitle → String?
-
final
- fileInThreadBuilder → Widget Function(BuildContext context, String path)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
messageBuilders
→ Map<
String, MessageBuilder> ? -
final
- messageHeaderBuilder → Widget Function(BuildContext, MeshDocument, MeshElement)?
-
final
-
messages
→ List<
MeshElement> -
final
- mobileStorageSaveSurfacePresenter → ThreadStorageSaveSurfacePresenter?
-
final
- mobileUnderHeaderContentPadding → double?
-
final
- onCancel → VoidCallback?
-
final
-
online
→ List<
Participant> -
final
-
onShowCompletedToolCallsChanged
→ ValueChanged<
bool> ? -
final
-
openFile
→ FutureOr<
void> Function(String path)? -
final
- path → String
-
final
- pendingItemId → String?
-
final
-
pendingMessages
→ List<
PendingAgentMessage> -
final
- room → RoomClient?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollController → ScrollController
-
final
- shouldShowAuthorNames → bool
-
final
- showCompletedToolCalls → bool
-
final
- showListening → bool
-
final
- showTyping → bool
-
final
- startChatCentered → bool
-
final
- threadStatus → String?
-
final
- threadStatusLinesAdded → int?
-
final
- threadStatusLinesRemoved → int?
-
final
- threadStatusMode → String?
-
final
- threadStatusStartedAt → DateTime?
-
final
- threadStatusTotalBytes → int?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ChatThreadMessages> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited