ChatThreadSnapshot class
Constructors
-
ChatThreadSnapshot({required List<
MeshElement> messages, required List<Participant> online, required List<String> offline, required List<String> typing, required List<String> listening, required bool agentOnline, required String? threadStatus, required DateTime? threadStatusStartedAt, required String? threadStatusMode, required int? threadStatusTotalBytes, required int? threadStatusLinesAdded, required int? threadStatusLinesRemoved, required bool supportsAgentMessages, required bool supportsMcp, required Map<String, ToolkitCapabilities> toolkits, required String? threadTurnId, required List<PendingAgentMessage> pendingMessages, required String? pendingItemId, required AgentUsageSnapshot? usage})
Properties
- agentOnline → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
listening
→ List<
String> -
final
-
messages
→ List<
MeshElement> -
final
-
offline
→ List<
String> -
final
-
online
→ List<
Participant> -
final
- pendingItemId → String?
-
final
-
pendingMessages
→ List<
PendingAgentMessage> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsAgentMessages → bool
-
final
- supportsMcp → bool
-
final
- threadStatus → String?
-
final
- threadStatusLinesAdded → int?
-
final
- threadStatusLinesRemoved → int?
-
final
- threadStatusMode → String?
-
final
- threadStatusStartedAt → DateTime?
-
final
- threadStatusTotalBytes → int?
-
final
- threadTurnId → String?
-
final
-
toolkits
→ Map<
String, ToolkitCapabilities> -
final
-
typing
→ List<
String> -
final
- usage → AgentUsageSnapshot?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited