ChatThreadSnapshot class
Constructors
-
ChatThreadSnapshot({required List<
MeshElement> messages, required List<Participant> online, required List<String> offline, required List<String> typing, required List<String> listening, required List<ThreadToolkitBuilder> availableTools, required bool agentOnline, required String? threadStatus, required String? threadStatusMode})
Properties
- agentOnline → bool
-
final
-
availableTools
→ List<
ThreadToolkitBuilder> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
listening
→ List<
String> -
final
-
messages
→ List<
MeshElement> -
final
-
offline
→ List<
String> -
final
-
online
→ List<
Participant> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- threadStatus → String?
-
final
- threadStatusMode → String?
-
final
-
typing
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited