PendingAgentMessage class
Constructors
-
PendingAgentMessage({required String messageId, required String messageType, required String threadPath, required String text, required List<
AgentFileContent> attachments, String? senderName, DateTime? createdAt, bool matchByContentOnly = false, bool awaitingAcceptance = false, bool awaitingApplication = false, bool awaitingOnline = false}) -
const
- PendingAgentMessage.fromAcceptedMessage(TurnStartAccepted message)
-
factory
-
PendingAgentMessage.fromQueueJson(Map<
String, dynamic> json) -
factory
- PendingAgentMessage.fromTurnInputMessage(AgentThreadMessage message)
-
factory
Properties
-
attachments
→ List<
AgentFileContent> -
final
- awaitingAcceptance → bool
-
final
- awaitingApplication → bool
-
final
- awaitingOnline → bool
-
final
- createdAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasVisibleContent → bool
-
no setter
- matchByContentOnly → bool
-
final
- messageId → String
-
final
- messageType → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderName → String?
-
final
- text → String
-
final
- threadPath → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited