ThreadStorageSaveSurfaceRequest class
Constructors
-
ThreadStorageSaveSurfaceRequest({required RoomClient room, required String title, required String suggestedFileName, required String fileNameLabel, required Future<
FileContent> loadContent()}) -
const
Properties
- fileNameLabel → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
loadContent
→ Future<
FileContent> Function() -
final
- room → RoomClient
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suggestedFileName → String
-
final
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited