DatasetThreadImage class

Constructors

DatasetThreadImage({String? generationId, String? uri, String? imageId, String? mimeType, String? status, String? statusDetail, double? width, double? height, String? sourcePrompt, String? prompt})
const

Properties

effectivePrompt String?
no setter
generationId String?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
imageId String?
final
mimeType String?
final
prompt String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourcePrompt String?
final
status String?
final
statusDetail String?
final
uri String?
final
width double?
final

Methods

copyWith({String? sourcePrompt}) DatasetThreadImage
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited