RoomDatasetChatThread class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- RoomDatasetChatThread
Constructors
-
RoomDatasetChatThread({Key? key, required RoomClient room, required String path, ChatThreadController? controller, GlobalKey<
State< ? composerKey, String? agentName, String? emptyStateTitle, String? emptyStateDescription, FutureOr<StatefulWidget> >void> openFile(String path)?, DatasetChatAttachmentRenderer? attachmentRenderer, DatasetChatInlineAttachmentViewerPredicate? inlineAttachmentViewerPredicate, Widget toolsBuilder(BuildContext, ChatThreadController, ChatThreadSnapshot)?, Widget? inputPlaceholder, Widget attachmentBuilder(BuildContext context, FileAttachment upload)?, ChatThreadCustomInputBuilder? customInputBuilder, EditableTextContextMenuBuilder? inputContextMenuBuilder, TapRegionCallback? inputOnPressedOutside, FileDropOverlayBuilder? fileDropOverlayBuilder, DatasetChatModelController? modelController, bool initialShowCompletedToolCalls = false, }) -
const
Properties
- agentName → String?
-
final
- attachmentBuilder → Widget Function(BuildContext context, FileAttachment upload)?
-
final
- attachmentRenderer → DatasetChatAttachmentRenderer?
-
final
-
composerKey
→ GlobalKey<
State< ?StatefulWidget> > -
final
- controller → ChatThreadController?
-
final
- customInputBuilder → ChatThreadCustomInputBuilder?
-
final
- emptyStateDescription → String?
-
final
- emptyStateTitle → String?
-
final
- fileDropOverlayBuilder → FileDropOverlayBuilder?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialShowCompletedToolCalls → bool
-
final
- inlineAttachmentViewerPredicate → DatasetChatInlineAttachmentViewerPredicate?
-
final
- inputContextMenuBuilder → EditableTextContextMenuBuilder?
-
final
- inputOnPressedOutside → TapRegionCallback?
-
final
- inputPlaceholder → Widget?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- modelController → DatasetChatModelController?
-
final
-
openFile
→ FutureOr<
void> Function(String path)? -
final
- path → String
-
final
- room → RoomClient
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
- toolsBuilder → Widget Function(BuildContext, ChatThreadController, ChatThreadSnapshot)?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< RoomDatasetChatThread> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited