MatrixMapReadOnly<T> class
abstract
A read only interface for instances of MatrixMap
- Implementers
Constructors
Properties
Methods
-
computeSize(
) → IntVector2 - Calculate the horizontal and vertical edges of the matrix.
-
elementAt(
{required int colIndex, required int rowIndex}) → T? - Get item in a specific position
-
forEach(
MatrixMapIterator< T> iterate) → void - Iterate in all items of this matrix map
-
forEachExistingItemOn(
{required Iterable< int> colIndices, required Iterable<int> rowIndices, required MatrixMapIterator<T> iterate}) → void - Iterate in all existing items in a given list of columns and rows.
-
forEachInRange(
{required Iterable< int> colIndices, required Iterable<int> rowIndices}) → Iterable<MatrixMapIterableResult< T?> > - Iterates all positions in the given list of columns and rows.
-
forEachInRow(
int rowIndex, MatrixMapIterator< T> iterate) → void - Iterate in all items of this matrix map in a specific row.
-
forEachPositionOn(
{required Iterable< int> colIndices, required Iterable<int> rowIndices, required MaybeMatrixMapIterator<T> iterate}) → void - Iterate in all positions, with existing items or not in a given list of columns and rows.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
IntVector2 coordinate) → T? -
Get element at a position corresponding to
coordinate.