Range2D class
- Implementers
- Annotations
Constructors
- Range2D.fromLTRB(IntVector2 leftTop, IntVector2 rightBottom)
-
const
- Range2D.fromLTWH(IntVector2 leftTop, IntVector2 size)
-
const
- Range2D.fromPoints(IntVector2 a, IntVector2 b)
- Range2D.fromSides(Range horizontal, Range vertical)
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isNil → bool
-
no setter
- leftBottom → IntVector2
-
no setter
- leftTop → IntVector2
-
final
- rightBottom → IntVector2
-
final
- rightTop → IntVector2
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → IntVector2
-
no setter
- xRange → Range
-
no setter
- yRange → Range
-
no setter
Methods
-
containsRange(
Range2D otherRange) → bool -
Defines if this range contains
otherRangeentirely -
containsVector(
IntVector2 intVector2) → bool - Defines if this range contains a specific vector
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
overlaps(
Range2D otherRange) → bool -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator &(
Range2D other) → Range2D -
operator ==(
Object other) → bool -
The equality operator.
override