data_grid/swayze/src/config library
Constants
- kColumnHeaderHeight → const double
- The height of the column headers.
- kDefaultCellHeight → const double
- kDefaultCellWidth → const double
- kDefaultScrollAnimationCurve → const Cubic
- kDefaultScrollAnimationDuration → const Duration
- kRowHeaderWidth → const double
- The starting width of row headers.
Functions
-
headerWidthForRange(
Range range) → double -
Get the width of the rows headers given the actual
range, this adjusts the size of the header to show larger numbers.