AutoScrollDragScrollData class
DragScrollData for automatic scroll from a drag gesture.
Used to transport information from getHorizontalDragScrollData or getVerticalDragScrollData that identifies when a drag gesture on TableBodyGestureDetector or HeaderGestureDetector may cause auto scroll when the gesture reaches the edges of the screen.
Used to kick start a AutoScrollActivity.
- Implemented types
Constructors
- AutoScrollDragScrollData({required AxisDirection direction, required double pointerDistance, double? maxToScroll})
-
const
Properties
- direction → AxisDirection
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxToScroll → double?
-
final
- pointerDistance → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited