data_grid/swayze/src/widgets/table library
Classes
-
SliverSwayzeTable<
CellDataType extends SwayzeCellData> - A sliver StatefulWidget that represents one single table on a scroll view.
- SliverSwayzeTableState
- This class is stateful due to its access via SwayzeScrollController.ensureTableVisibility.
Constants
- kColumnHeaderHeight → const double
- The height of the column headers.
- kDefaultCellHeight → const double
- kDefaultCellWidth → const double
- kDefaultScrollAnimationCurve → const Cubic
- kDefaultScrollAnimationDuration → const Duration
- kRowHeaderWidth → const double
- The starting width of row headers.
Functions
-
headerWidthForRange(
Range range) → double -
Get the width of the rows headers given the actual
range, this adjusts the size of the header to show larger numbers.
Typedefs
- InlineEditorBuilder = Widget Function(BuildContext context, IntVector2 coordinate, VoidCallback requestClose, {String? initialText, required bool overlapCell, required bool overlapTable})
- Type signature of functions that builds the widget that allows the editing of an individual cell in the same physical position as the once occupied by the cell in the table.