InMemoryTable class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- InMemoryTable
Constructors
-
InMemoryTable({Key? key, required List<
String> columns, required List<List< rows, double maxHeight = 420, bool autoSizeHorizontally = false, bool autoSizeVertically = false, bool autoSizeColumns = false, bool autoSizeRows = false, double? maxAutoSizeColumnExtent = 300, double? maxAutoSizeRowExtent = 300, bool showLeadingOuterBorders = false, bool showRowHeaders = true, ValueChanged<String> >Set< ? onSelectedRowsChanged, FutureOr<int> >void> onOpenFile(String file)?}) -
const
Properties
- autoSizeColumns → bool
-
final
- autoSizeHorizontally → bool
-
final
- autoSizeRows → bool
-
final
- autoSizeVertically → bool
-
final
-
columns
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxAutoSizeColumnExtent → double?
-
final
- maxAutoSizeRowExtent → double?
-
final
- maxHeight → double
-
final
-
onOpenFile
→ FutureOr<
void> Function(String file)? -
final
-
onSelectedRowsChanged
→ ValueChanged<
Set< ?int> > -
final
-
rows
→ List<
List< String> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showLeadingOuterBorders → bool
-
final
- showRowHeaders → bool
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< InMemoryTable> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited