SwayzeTableView class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SwayzeTableView
Constructors
-
SwayzeTableView({Key? key, required RoomClient room, required String tableName, required List<
String> ? namespace, String? sqliteDatabase, String? filter, String? sqlQuery, List<TableRef> ? sqlTables, ArrowSchema? displaySchema, String? branch, int? version, int reloadToken = 0, bool autoSizeHorizontally = false, bool autoSizeVertically = false, bool autoSizeColumns = false, bool autoSizeRows = false, double? maxAutoSizeColumnExtent = 300, double? maxAutoSizeRowExtent = 300, bool showLeadingOuterBorders = false, bool showRowHeaders = true, bool showStatusBar = true, bool showGridTopBorder = false, int cancelToken = 0, ValueChanged<SwayzeTableStatus> ? onStatusChanged, FutureOr<void> onOpenFile(String file)?, Stream<DatasetTableWatchEvent> ? tableWatchEvents, Widget? statusBarTrailing}) -
const
Properties
- autoSizeColumns → bool
-
final
- autoSizeHorizontally → bool
-
final
- autoSizeRows → bool
-
final
- autoSizeVertically → bool
-
final
- branch → String?
-
final
- cancelToken → int
-
final
- displaySchema → ArrowSchema?
-
final
- filter → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxAutoSizeColumnExtent → double?
-
final
- maxAutoSizeRowExtent → double?
-
final
-
namespace
→ List<
String> ? -
final
-
onOpenFile
→ FutureOr<
void> Function(String file)? -
final
-
onStatusChanged
→ ValueChanged<
SwayzeTableStatus> ? -
final
- reloadToken → int
-
final
- room → RoomClient
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showGridTopBorder → bool
-
final
- showLeadingOuterBorders → bool
-
final
- showRowHeaders → bool
-
final
- showStatusBar → bool
-
final
- sqliteDatabase → String?
-
final
- sqlQuery → String?
-
final
-
sqlTables
→ List<
TableRef> ? -
final
- statusBarTrailing → Widget?
-
final
- tableName → String
-
final
-
tableWatchEvents
→ Stream<
DatasetTableWatchEvent> ? -
final
- version → int?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< SwayzeTableView> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited