MultiSelectAutocomplete class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MultiSelectAutocomplete
Constructors
-
MultiSelectAutocomplete({Key? key, required AsyncSearch search, ValueChanged<
List< ? onChanged, TextStyle? style, BoxConstraints? constraints, bool? autofocus, FocusNode? focusNode, MultiSelectController? controller, TextEditingController? textController, ShadPopoverController? popoverController, Widget? placeholder, TextStyle? placeholderStyle, Duration debounceDuration = const Duration(milliseconds: 300), int minimumSearchLength = 2, List<String> >String> ? initialValue, int? maxSelected, MultiSelectItemBuilder? optionBuilder, MultiSelectItemBuilder? selectedItemBuilder}) -
const
Properties
- autofocus → bool?
-
final
- constraints → BoxConstraints?
-
final
- controller → MultiSelectController?
-
final
- debounceDuration → Duration
-
final
- focusNode → FocusNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
initialValue
→ List<
String> ? -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxSelected → int?
-
final
- minimumSearchLength → int
-
final
-
onChanged
→ ValueChanged<
List< ?String> > -
final
- optionBuilder → MultiSelectItemBuilder?
-
final
- placeholder → Widget?
-
final
- placeholderStyle → TextStyle?
-
final
- popoverController → ShadPopoverController?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- search → AsyncSearch
-
final
- selectedItemBuilder → MultiSelectItemBuilder?
-
final
- style → TextStyle?
-
final
- textController → TextEditingController?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited