ThreadAttachmentImageCache class
Constructors
- ThreadAttachmentImageCache({int maximumBytes = 32 * 1024 * 1024})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maximumBytes → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void -
load(
{String? imageId, String? imageUri, required Future< ThreadAttachmentImageData?> loader()}) → Future<ThreadAttachmentImageData?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
{String? imageId, String? imageUri}) → ThreadAttachmentImageData? -
toString(
) → String -
A string representation of this object.
inherited
-
write(
{String? imageId, String? imageUri, required Uint8List data, required String mimeType}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited